@@ -46,12 +46,12 @@ class CfnPipeline(
         id: builtins.str,
         *,
         name: builtins.str,
-        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
+        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
         activate: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
-        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]] = None,
-        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
-        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
+        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
     ) -> None:
         '''Create a new ``AWS::DataPipeline::Pipeline``.
 
@@ -353,7 +353,7 @@ class CfnPipeline(
         def __init__(
             self,
             *,
-            attributes: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]],
+            attributes: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]],
             id: builtins.str,
         ) -> None:
             '''
@@ -458,7 +458,7 @@ class CfnPipeline(
         def __init__(
             self,
             *,
-            fields: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]],
+            fields: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]],
             id: builtins.str,
             name: builtins.str,
         ) -> None:
@@ -586,12 +586,12 @@ class CfnPipelineProps:
         self,
         *,
         name: builtins.str,
-        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, aws_cdk.core.IResolvable]]],
+        parameter_objects: typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[CfnPipeline.ParameterObjectProperty, aws_cdk.core.IResolvable]]],
         activate: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]] = None,
         description: typing.Optional[builtins.str] = None,
-        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.ParameterValueProperty]]]] = None,
-        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]] = None,
-        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]] = None,
+        parameter_values: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.ParameterValueProperty]]]] = None,
+        pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]] = None,
+        pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.Sequence[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]] = None,
     ) -> None:
         '''Properties for defining a ``AWS::DataPipeline::Pipeline``.
 
